#!/usr/bin/env python

import berserk, subprocess, pickle
from os import path

# Change ACCESS TOKEN according to your need
ACCESS_TOKEN=""
NOTIFY_DURATION=15*60 # Notification duration in seconds
CACHE_FILE="/tmp/lichess_notify_cache" # Change this according to your needs

# Notify using notify-send
def notify_send(summary, message):
    subprocess.Popen(['notify-send', '-u', 'critical','-t', str(NOTIFY_DURATION*1000), summary, message])
    return


# Check if notify already done
def notify_done(key):
    if not(path.exists(CACHE_FILE)):
        return(False)
    else:
        with open(CACHE_FILE, 'rb') as f:
            keys=pickle.load(f)
            return(key in keys)

# Save notify key in cache
def add_key(key):
    if not(path.exists(CACHE_FILE)):
        with open(CACHE_FILE, 'wb') as f:
            pickle.dump([key],f)
            f.close()
    else:
        keys=list()
        with open(CACHE_FILE, 'rb') as f:
            keys=pickle.load(f)
            f.close()
        if not(key in keys):
            keys.append(key)
        with open(CACHE_FILE, 'wb') as f:
            pickle.dump(keys,f)
            f.close()

# Fetch data and notify
session = berserk.TokenSession(ACCESS_TOKEN)
client = berserk.Client(session=session)
data=client.games.get_ongoing()
for game in data:
    opponent=game["opponent"]["username"]
    lastMove=game["lastMove"]
    key=opponent+lastMove
    if game["isMyTurn"]:
        if not(notify_done(key)):
            notify_send("Lichess.org ("+opponent+")","It is your turn !\n Your opponent played "+lastMove)
            add_key(key)

